.. currentmodule:: pysdic.geometry

pysdic.geometry.IntegrationPoints
===========================================

.. autoclass:: IntegrationPoints


Accessing IntegrationPoints attributes
-------------------------------------------

.. autosummary::
   :toctree: ../generated/

    IntegrationPoints.element_indices
    IntegrationPoints.internal_bypass
    IntegrationPoints.n_dimensions
    IntegrationPoints.n_points
    IntegrationPoints.n_valids
    IntegrationPoints.natural_coordinates
    IntegrationPoints.shape
    IntegrationPoints.weights

Manipulating IntegrationPoints objects
-------------------------------------------

.. autosummary::
   :toctree: ../generated/

    IntegrationPoints.add_points
    IntegrationPoints.copy
    IntegrationPoints.disable_points
    IntegrationPoints.remove_invalids
    IntegrationPoints.remove_points
    IntegrationPoints.validate

